The **seeq** Python library is used to interface with Seeq Server ([http://www.seeq.com](http://www.seeq.com)).


----------

In case you are looking for the Gencove package, it is available here: https://pypi.org/project/gencove/ 